using System;
using System.Runtime.Serialization;
using System.Security.Permissions;

namespace Wax
{
    /// <summary>
    /// Parse exception that is thrown if an invalid or unknown find method is encountered during parsing.
    /// </summary>
    [Serializable]
    public class InvalidFindMethodException : ParseException
    {
        /// <summary>
        /// Gets or sets the invalid method.
        /// </summary>
        /// <value>The invalid method.</value>
        public string InvalidMethodName { get; private set; }

        /// <summary>
        /// Initializes a new instance of the <see cref="InvalidFindMethodException"/> class.
        /// </summary>
        public InvalidFindMethodException()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="InvalidFindMethodException"/> class.
        /// </summary>
        public InvalidFindMethodException(string invalidMethodName)
        {
            InvalidMethodName = invalidMethodName;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="InvalidFindMethodException"/> class.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="innerException">The inner exception.</param>
        public InvalidFindMethodException(string message, Exception innerException) : base(message, innerException)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="InvalidFindMethodException"/> class.
        /// </summary>
        /// <param name="info">The <see cref="T:System.Runtime.Serialization.SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
        /// <param name="context">The <see cref="T:System.Runtime.Serialization.StreamingContext"/> that contains contextual information about the source or destination.</param>
        /// <exception cref="T:System.ArgumentNullException">The <paramref name="info"/> parameter is null. </exception>
        /// <exception cref="T:System.Runtime.Serialization.SerializationException">The class name is null or <see cref="P:System.Exception.HResult"/> is zero (0). </exception>
        protected InvalidFindMethodException(SerializationInfo info, StreamingContext context) : base(info, context)
        {
            if (info != null)
            {
                this.InvalidMethodName = info.GetString("invalidMethodName");
            }
        }

        /// <summary>
        /// When overridden in a derived class, sets the <see cref="T:System.Runtime.Serialization.SerializationInfo"/> with information about the exception.
        /// </summary>
        /// <param name="info">The <see cref="T:System.Runtime.Serialization.SerializationInfo"/> that holds the serialized object data about the exception being thrown.</param>
        /// <param name="context">The <see cref="T:System.Runtime.Serialization.StreamingContext"/> that contains contextual information about the source or destination.</param>
        /// <exception cref="T:System.ArgumentNullException">The <paramref name="info"/> parameter is a null reference (Nothing in Visual Basic). </exception>
        /// <PermissionSet>
        /// 	<IPermission class="System.Security.Permissions.FileIOPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Read="*AllFiles*" PathDiscovery="*AllFiles*"/>
        /// 	<IPermission class="System.Security.Permissions.SecurityPermission, mscorlib, Version=2.0.3600.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" version="1" Flags="SerializationFormatter"/>
        /// </PermissionSet>
        [SecurityPermission(SecurityAction.LinkDemand, Flags = SecurityPermissionFlag.SerializationFormatter)]
        public override void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            base.GetObjectData(info, context);

            if (info != null)
            {
                info.AddValue("invalidMethodName", this.InvalidMethodName);
            }
        }
    }
}